pub async fn estimate_transport(
    configuration: &Configuration,
    shipment_id: &str
) -> Result<EstimateTransportResponse, Error>
Initiates the process of estimating the shipping cost for an inbound shipment by an Amazon-partnered carrier. Prior to calling the estimateTransport operation, you must call the putTransportDetails operation to provide Amazon with the transportation information for the inbound shipment. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.