pub async fn get_inbound_guidance(
    configuration: &Configuration,
    marketplace_id: &str,
    seller_sku_list: Option<Vec<String>>,
    asin_list: Option<Vec<String>>
) -> Result<GetInboundGuidanceResponse, Error>
Returns information that lets a seller know if Amazon recommends sending an item to a given marketplace. In some cases, Amazon provides guidance for why a given SellerSKU or ASIN is not recommended for shipment to Amazon’s fulfillment network. Sellers may still ship items that are not recommended, at their discretion. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.