pub async fn get_shipment_items(
    configuration: &Configuration,
    query_type: &str,
    marketplace_id: &str,
    last_updated_after: Option<String>,
    last_updated_before: Option<String>,
    next_token: Option<&str>
) -> Result<GetShipmentItemsResponse, Error>
Returns a list of items in a specified inbound shipment, or a list of items that were updated within a specified time frame. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.